==> gnuastro_0.11.orig.tar.gz: gnuastro-0.11/tests/arithmetic/snimage.sh <==
# Make an S/N image to test Arithmetic.
#
# See the Tests subsection of the manual for a complete explanation
# (in the Installing gnuastro section).
#
# Original author:
#     Mohammad Akhlaghi <mohammad@akhlaghi.org>
# Contributing author(s):
# Copyright (C) 2015-2019 Free Software Foundation, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.





# Preliminaries
# =============
#
# Set the variables (The executable is in the build tree). Do the
# basic checks to see if the executable is made or if the defaults
# file exists (basicchecks.sh is in the source tree).
prog=arithmetic
execname=../bin/$prog/ast$prog
imgin=convolve_spatial_noised.fits
imgnc=convolve_spatial_noised_detected.fits





# Skip?
# =====
#
# If the dependencies of the test don't exist, then skip it. There are two
# types of dependencies:
#
#   - The executable was not made (for example due to a configure option),
#
#   - The input data was not made (for example the test that created the
#     data file failed).
if [ ! -f $execname ]; then echo "$execname not created."; exit 77; fi
if [ ! -f $imgin    ]; then echo "$imgin does not exist."; exit 77; fi
if [ ! -f $imgnc    ]; then echo "$imgnc does not exist."; exit 77; fi





# Actual test script
# ==================
#
# `check_with_program' can be something like `Valgrind' or an empty
# string. Such programs will execute the command if present and help in
# debugging when the developer doesn't have access to the user's system.
$check_with_program $execname $imgin $imgnc - $imgnc / --hdu=1 --hdu=SKY  \
                               --hdu=SKY_STD  --output=snimage.fits

==> gnuastro-0.12.tar.gz: gnuastro-0.12/tests/arithmetic/snimage.sh <==
# Make an S/N image to test Arithmetic.
#
# See the Tests subsection of the manual for a complete explanation
# (in the Installing gnuastro section).
#
# Original author:
#     Mohammad Akhlaghi <mohammad@akhlaghi.org>
# Contributing author(s):
# Copyright (C) 2015-2020, Free Software Foundation, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.





# Preliminaries
# =============
#
# Set the variables (The executable is in the build tree). Do the
# basic checks to see if the executable is made or if the defaults
# file exists (basicchecks.sh is in the source tree).
prog=arithmetic
execname=../bin/$prog/ast$prog
imgin=convolve_spatial_noised.fits
imgnc=convolve_spatial_noised_detected.fits





# Skip?
# =====
#
# If the dependencies of the test don't exist, then skip it. There are two
# types of dependencies:
#
#   - The executable was not made (for example due to a configure option),
#
#   - The input data was not made (for example the test that created the
#     data file failed).
if [ ! -f $execname ]; then echo "$execname not created."; exit 77; fi
if [ ! -f $imgin    ]; then echo "$imgin does not exist."; exit 77; fi
if [ ! -f $imgnc    ]; then echo "$imgnc does not exist."; exit 77; fi





# Actual test script
# ==================
#
# 'check_with_program' can be something like Valgrind or an empty
# string. Such programs will execute the command if present and help in
# debugging when the developer doesn't have access to the user's system.
$check_with_program $execname $imgin $imgnc - $imgnc / --hdu=1 --hdu=SKY  \
                               --hdu=SKY_STD  --output=snimage.fits
